




******

From the Desk of Mr. Readme:

Bravo!  You have received a Medical Diploma from       
the Orbital Convergence University International Air    
and Water Embassy of the Rust on the Beach Planet.      

You are now officially certified to include   
this treasure in your practice.   

Encore!

******


# womb (silicon etching)
`#scifi`

---

## summary

	
---		
		
## obtain
```
pip install womb
```


## on
```
womb on
```





